@@ -27,8 +27,12 @@ class AlarmThread(threading.Thread):
 		            if now.strftime("%H:%M") == self.parent.events[event]["Time"]:
                                 self.parent.alarm = event
 
-			        self.parent.audioPlayer.play(self.parent.configuration.get("Settings", "soundPath"))
-                                if self.parent.configuration.getboolean("Settings", "autostopalarm"):
+			        self.parent.audioPlayer.play(
+self.parent.configuration.soundpath, 
+self.parent.configuration.volume,
+self.parent.configuration.backuppath
+)
+                                if self.parent.configuration.autostopalarm:
                                     import gobject
                                     gobject.timeout_add(60 * 60000, self.parent.stop_alarm)
 			        self.parent.events[event]["Last"] = date
