@@ -16,19 +16,68 @@ CONFIG_FILE_NAME = "wakeupcall.config.ini"
 CONFIG_FILE_TEMPLATE_NAME = "wakeupcall.config.ini.template"
 DATA_DIR = "/usr/share/wakeupcall/"
 
-def read_configuration():
-    configFile = os.path.join(CONFIG_FILE_PATH, CONFIG_FILE_NAME)
-    if not os.path.exists(CONFIG_FILE_PATH):
-        os.makedirs(CONFIG_FILE_PATH)
-	shutil.copy(os.path.join(DATA_DIR, CONFIG_FILE_TEMPLATE_NAME), configFile)
-    configuration = ConfigParser.ConfigParser()
-    configuration.read(configFile)
-    return configuration
+class Configuration:
 
-def write_configuration(configuration):
-    configFile = open(os.path.join(CONFIG_FILE_PATH, CONFIG_FILE_NAME), "w")
-    configuration.write(configFile)
-    configFile.close()
+    def __init__(self):
+        self.read_configuration()
+
+    def read_configuration(self):
+        configFile = os.path.join(CONFIG_FILE_PATH, CONFIG_FILE_NAME)
+        if not os.path.exists(CONFIG_FILE_PATH):
+            os.makedirs(CONFIG_FILE_PATH)
+	    shutil.copy(os.path.join(DATA_DIR, CONFIG_FILE_TEMPLATE_NAME), configFile)
+        self.configuration = ConfigParser.ConfigParser()
+        self.configuration.read(configFile)
+        try:
+            self.volume = self.configuration.getint("Settings", "volume")
+        except ConfigParser.NoOptionError, e:
+            self.volume = 90 # default
+        try:
+            self.fullscreen = self.configuration.getboolean("Settings", "fullscreen")
+        except ConfigParser.NoOptionError, e:
+            self.fullscreen = True # default
+        try:
+            self.screenalwayson = self.configuration.getboolean("Settings", "screenalwayson")
+        except ConfigParser.NoOptionError, e:
+            self.screenalwayson = False # default
+        try:
+            self.showdate = self.configuration.getboolean("Settings", "showdate")
+        except ConfigParser.NoOptionError, e:
+            self.showdate = False # default
+        try:
+            self.autostopalarm = self.configuration.getboolean("Settings", "autostopalarm")
+        except ConfigParser.NoOptionError, e:
+            self.autostopalarm = True # default
+        try:
+            self.soundpath = self.configuration.get("Settings", "soundpath")
+        except ConfigParser.NoOptionError, e:
+            self.soundpath = "http://www.wdr.de/wdrlive/media/mp3/wdr5.m3u" # default
+        try:
+            self.backuppath = self.configuration.get("Settings", "backuppath")
+        except ConfigParser.NoOptionError, e:
+            self.backuppath = "/usr/share/wakeupcall/default/alarm.mp3" # default
+        try:
+            self.themepath = self.configuration.get("Settings", "themepath")
+        except ConfigParser.NoOptionError, e:
+            self.themepath = "/usr/share/wakeupcall/default/" # default
+        try:
+            self.usebrightnesssensor = self.configuration.getboolean("Settings", "usebrightnesssensor")
+        except ConfigParser.NoOptionError, e:
+            self.usebrightnesssensor = True # default
+
+    def write_configuration(self):
+        configFile = open(os.path.join(CONFIG_FILE_PATH, CONFIG_FILE_NAME), "w")
+        self.configuration.set("Settings", "volume", self.volume)
+        self.configuration.set("Settings", "fullscreen", self.fullscreen)
+        self.configuration.set("Settings", "screenalwayson", self.screenalwayson)
+        self.configuration.set("Settings", "showdate", self.showdate)
+        self.configuration.set("Settings", "autostopalarm", self.autostopalarm)
+        self.configuration.set("Settings", "themepath", self.themepath)
+        self.configuration.set("Settings", "backuppath", self.backuppath)
+        self.configuration.set("Settings", "usebrightnesssensor", self.usebrightnesssensor)
+        self.configuration.set("Settings", "soundpath", self.soundpath)
+        self.configuration.write(configFile)
+        configFile.close()
 
 class ConfigButton(QLabel):
     def __init__(self, image, parent=None):
@@ -66,7 +115,8 @@ class MainWindow(QtGui.QWidget):
     
     def __init__(self):
         super(MainWindow, self).__init__()
-        self.configuration = read_configuration()
+        #self.configuration = read_configuration()
+        self.configuration = Configuration()
 
         from player import AudioPlayer        
         self.audioPlayer = AudioPlayer()
@@ -99,19 +149,20 @@ class MainWindow(QtGui.QWidget):
         layout.addWidget(self.frame, 0, 0, 5, 4)
         self.setLayout(layout)
      
-        if self.configuration.getboolean("Settings", "fullscreen"):
+        if self.configuration.fullscreen:
             self.showFullScreen()
 
     def open_config(self):
         dia = ConfigDialog(self)
         dia.exec_()
-        write_configuration(self.configuration)
-	self.loadImages()
+        #write_configuration(self.configuration)
+	self.configuration.write_configuration()
+        self.loadImages()
         self.update_gui()
         self.send_out_the_buttons()
 
     def update_gui(self):
-        if self.configuration.getboolean("Settings", "fullscreen"):
+        if self.configuration.fullscreen:
             self.showFullScreen()
         else:
             self.showNormal()
@@ -125,7 +176,7 @@ class MainWindow(QtGui.QWidget):
     def turn_on_screen(self):
         # Bugfix because pyqt on maemo is broken
         import osso
-        if self.configuration.getboolean("Settings", "screenAlwaysOn"):
+        if self.configuration.screenalwayson or self.alarmManager.alarm != "":
             osso_c = osso.Context("osso_test_device_on", "0.0.1", False)
             device = osso.DeviceState(osso_c)
             device.display_state_on()
@@ -149,7 +200,7 @@ class MainWindow(QtGui.QWidget):
         self.quitButton.setVisible(True)
         self.configButton.setVisible(True)
         buttonYPositionMax = self.screenHeight - buttonRect.height() - self.statusBarHeight
-        if self.configuration.getboolean("Settings", "fullscreen"):
+        if self.configuration.fullscreen:
             buttonYPositionMax = self.screenHeight - buttonRect.height()
         if self.buttonYPosition >= buttonYPositionMax:
             self.buttonYPosition -= self.buttonSpeed
@@ -162,7 +213,7 @@ class MainWindow(QtGui.QWidget):
     def send_out_the_buttons(self):
 	buttonRect = self.confImage.rect()
         buttonYPositionMin = self.screenHeight + buttonRect.height() + self.statusBarHeight
-        if self.configuration.getboolean("Settings", "fullscreen"):
+        if self.configuration.fullscreen:
             buttonYPositionMin = self.screenHeight + buttonRect.height()
         if self.buttonYPosition <= buttonYPositionMin:
             self.buttonYPosition += self.buttonSpeed
@@ -175,7 +226,7 @@ class MainWindow(QtGui.QWidget):
             self.timer.stop()
 
     def loadImages(self):
-        themePath = self.configuration.get("Settings", "themePath")
+        themePath = self.configuration.themepath
 
 	self.stopImage = QtGui.QImage()
 	self.stopImage.load(themePath + "/stop.png")
@@ -236,7 +287,7 @@ class Frame(QtGui.QFrame):
 
         xStart = 185
         yStart = 125
-        if self.parent.configuration.getboolean("Settings", "fullscreen"):
+        if self.parent.configuration.fullscreen:
             yStart += self.parent.statusBarHeight
 
         time = QtCore.QTime.currentTime()
@@ -262,7 +313,7 @@ class Frame(QtGui.QFrame):
         self.paintDigits(painter, xStart + 312, yStart + 30, sec0)
         self.paintDigits(painter, xStart + 364, yStart + 30, sec1)
         
-        if self.parent.configuration.getboolean("Settings", "showDate"):
+        if self.parent.configuration.showdate:
             today = datetime.datetime.today()
             painter.drawText(420, yStart+130, today.strftime("%A, %d.%m.%y"))
 
